<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DialogMsg</name>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="17"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="29"/>
        <source>&amp;Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="42"/>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="55"/>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="68"/>
        <source>text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="90"/>
        <source>type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="109"/>
        <source>cipher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="125"/>
        <source>key size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="141"/>
        <source>device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="160"/>
        <source>loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="179"/>
        <source>offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="195"/>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="243"/>
        <source>size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="211"/>
        <source>mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="227"/>
        <source>fs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="259"/>
        <source>used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="275"/>
        <source>unused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="291"/>
        <source>used %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.ui" line="307"/>
        <source>active slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="93"/>
        <source>
&quot;system volumes&quot; are volumes that either udev has identify them as such if udev is enabled or have an entry in &quot;/etc/fstab&quot;,&quot;/etc/crypttab&quot; or &quot;/etc/zuluCrypt/system_volumes.list&quot;.

If you prefer for a volume not to be considered a system volume,start the toolfrom root account and then go to &quot;menu-&gt;options-&gt;manage non system partitions&quot; and add the volume to the list and the volume will stop being considered as &quot;system&quot;.

Alternatively,you can add yourself to group &quot;zulucrypt&quot; and &quot;zulumount&quot; and all restrictions will go away.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="102"/>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="121"/>
        <source>INFORMATION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="113"/>
        <source>Insufficient privilege to access a system device,
only root user or members of group zulucrypt can do that</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="115"/>
        <source>Insufficient privilege to access a system device in read/write mode,
only root user or members of group zulucrypt-write can do that</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="118"/>
        <source>You do not seem to have proper permissions to access the encrypted file in %1 mode,check file permissions and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/dialogmsg.cpp" line="309"/>
        <source>Do not show this dialog again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="151"/>
        <source>
options:
	-d   path to where a volume to be auto unlocked/mounted is located
	-m   tool to use to open a default file manager(default tool is xdg-open)
	-e   start the application without showing the GUI
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1221"/>
        <source>Manage Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1257"/>
        <source>about zuluCrypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1491"/>
        <source>hmac plugin.

This plugin generates a key using below formular:

key = hmac(sha256,passphrase,keyfile contents)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1496"/>
        <source>keykeyfile plugin.

This plugin generates a key using below formular:

key = passphrase + keyfile contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1501"/>
        <source>gpg plugin.

This plugin retrives a key locked in a gpg file with a symmetric key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1519"/>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1519"/>
        <source>Could not find &quot;gpg&quot; executable in &quot;/usr/local/bin&quot;,&quot;/usr/bin&quot; and &quot;/usr/sbin&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1687"/>
        <source>INFO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="1687"/>
        <source>Translation will be done the next time you restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.cpp" line="639"/>
        <source>if the option is checked,a primary private mount point will be created in &quot;/run/media/private/$USER/&quot;
and a secondary publicly accessible &quot;mirror&quot; mount point will be created in &quot;/run/media/public/&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="284"/>
        <source>List Is Empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VeraCryptPIMDialog</name>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="14"/>
        <source>VeraCrypt PIM value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="26"/>
        <source>&amp;Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="39"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="52"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.cpp" line="38"/>
        <source>Set VeraCrypt dynamic mode magic number below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.cpp" line="85"/>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/veracryptpimdialog.cpp" line="85"/>
        <source>Failed to convert the value to digits only </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>deviceOffset</name>
    <message>
        <location filename="../../zuluMount-gui/deviceoffset.ui" line="26"/>
        <source>location could be in sectors if the entry is made up of only digits
or in bytes if the entry ends with &quot;b&quot;
or in kilobytes if the entry ends with &quot;k&quot;
or in megabytes if the entry ends with &quot;m&quot;
or in terabytes if the entry ends with &quot;t&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/deviceoffset.ui" line="48"/>
        <source>Enter Below The Offset Location Of The Volume About To Be Opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/deviceoffset.ui" line="80"/>
        <source>Enter The Password Below To A Volume At The Above Offset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/deviceoffset.ui" line="109"/>
        <source>&amp;Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/deviceoffset.ui" line="122"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>keyDialog</name>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="17"/>
        <source>unlock and mount a luks volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="29"/>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="45"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="58"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="139"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="770"/>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="100"/>
        <source>Mount Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="142"/>
        <source>Mount In &amp;Read Only Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="155"/>
        <source>&amp;Share Mount Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.ui" line="168"/>
        <source>O&amp;ptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="404"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="445"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="450"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="455"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="460"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="465"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="470"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="475"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="478"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="529"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="538"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="551"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="685"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="708"/>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="685"/>
        <source>An error has occured and the volume could not be opened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="71"/>
        <source>Mount A LUKS volume in &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="134"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="214"/>
        <source>Set File System Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="135"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="218"/>
        <source>Set Volume Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="136"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="222"/>
        <source>Set Volume As VeraCrypt Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="148"/>
        <source>TrueCrypt/VeraCrypt Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="137"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="226"/>
        <source>Set VeraCrypt PIM value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="140"/>
        <source>KeyFile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="141"/>
        <source>Key+KeyFile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="142"/>
        <source>Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="256"/>
        <source>Select A Folder To Create A Mount Point In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="308"/>
        <source>Select A File To Be Used As A Keyfile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="341"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="352"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="385"/>
        <source>ERROR!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="385"/>
        <source>Internal wallet is not configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="404"/>
        <source>The volume does not appear to have an entry in the wallet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="445"/>
        <source>Failed to unlock a cryfs volume.
Wrong password entered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="450"/>
        <source>Failed to unlock an encfs volume.
Wrong password entered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="455"/>
        <source>Failed to unlock a cryfs volume.
cryfs executable could not be found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="460"/>
        <source>Failed to unlock an encfs volume.
encfs executable could not be found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="465"/>
        <source>Failed to create mount point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="470"/>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="478"/>
        <source>Failed to unlock the volume.
Not supported volume encountered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="475"/>
        <source>Failed to unlock the volume.
Backend not responding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="529"/>
        <source>Plug in name field is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="538"/>
        <source>Keyfile field is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="760"/>
        <source>Plugin name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="780"/>
        <source>Keyfile path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="551"/>
        <source>&quot;/&quot; character is not allowed in the mount name field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="73"/>
        <source>Mount An Encrypted Volume In &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/keydialog.cpp" line="704"/>
        <source>ERROR: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mountOptions</name>
    <message>
        <location filename="../../zuluMount-gui/mountoptions.ui" line="14"/>
        <source>file system options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountoptions.ui" line="26"/>
        <source>&amp;Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountoptions.ui" line="42"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountoptions.ui" line="55"/>
        <source>Enter Comma Separated Volume&apos;s File System Options Below</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mountPartition</name>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="14"/>
        <source>select mount point path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="26"/>
        <source>Mount Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="45"/>
        <source>&amp;Mount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="77"/>
        <source>Use La&amp;bel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="100"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="116"/>
        <source>Mount &amp;Read Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="129"/>
        <source>&amp;Share Mount Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.ui" line="142"/>
        <source>&amp;Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="83"/>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="237"/>
        <source>Set File System Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="84"/>
        <source>Set Volume Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="152"/>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="209"/>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="152"/>
        <source>&quot;/&quot; character is not allowed in the mount name field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="206"/>
        <source>ERROR: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/mountpartition.cpp" line="251"/>
        <source>Select Path To Mount Point Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>oneinstance</name>
    <message>
        <location filename="../../zuluMount-gui/oneinstance.cpp" line="115"/>
        <source>There seem to be another instance running,exiting this one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/oneinstance.cpp" line="108"/>
        <source>Previous instance seem to have crashed,trying to clean up before starting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>utility::veraCryptWarning</name>
    <message>
        <location filename="../../zuluCrypt-gui/utility.h" line="535"/>
        <source>Elapsed time: 0 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.h" line="543"/>
        <source>Elapsed time: %0 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.h" line="545"/>
        <source>Elapsed time: %0 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluCrypt-gui/utility.h" line="556"/>
        <source>Please be patient as unlocking a VeraCrypt volume may take a very long time.

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>zuluMount</name>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="17"/>
        <source>zuluMount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="55"/>
        <source>Volume Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="63"/>
        <source>Mount Point Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="71"/>
        <source>File System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="79"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="87"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="95"/>
        <source>%Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="111"/>
        <source>Mount Encf&amp;s/Cryfs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="118"/>
        <source>&amp;Mount File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="131"/>
        <source>&amp;Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.ui" line="138"/>
        <source>&amp;Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="148"/>
        <source>Automount Volumes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="158"/>
        <source>Auto Open Mount Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="164"/>
        <source>Unmount All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="169"/>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="179"/>
        <source>Hide Volume From View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="189"/>
        <source>Unhide Volume From View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="200"/>
        <source>Select Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="204"/>
        <source>Check For Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="209"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="213"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="353"/>
        <source>Manage Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="502"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="512"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="522"/>
        <source>LABEL=&quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="524"/>
        <source>LABEL=&quot;%1&quot;
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="603"/>
        <source>Mount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="610"/>
        <source>Unmount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="1017"/>
        <source>Failed to unmount encfs/cryfs volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="591"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="620"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="637"/>
        <source>Open Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="623"/>
        <source>Open Private Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="625"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="645"/>
        <source>Open Shared Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="652"/>
        <source>Close Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="699"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="700"/>
        <source>Could not open mount point because &quot;%1&quot; tool does not appear to be working correctly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="726"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="734"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="864"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="1017"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="1026"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="1111"/>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="727"/>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="735"/>
        <source>Could not get volume properties.
volume is not open or was opened by a different user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="732"/>
        <source>Volume Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="865"/>
        <source>Permission to access the volume was denied
or
the volume is not supported
(LVM/MDRAID signatures found)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="891"/>
        <source>Select An Image File To Mount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="905"/>
        <source>Select An Encfs Volume Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../zuluMount-gui/zulumount.cpp" line="1112"/>
        <source>Reading partition properties took longer than expected and operation was terminated,click refresh to try again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
